@@ -1,12 +1,9 @@
-/* $Id: inphist.h,v 1.15 2004/01/04 15:05:37 jonas Exp $ */
-
 #ifndef EL__BFU_INPHIST_H
 #define EL__BFU_INPHIST_H
 
 #include "util/lists.h"
 
-struct terminal;
-struct window;
+struct dialog_data;
 
 
 struct input_history_entry {
@@ -21,6 +18,14 @@ struct input_history {
 	unsigned int nosave:1;
 };
 
+#define INIT_INPUT_HISTORY(history)				\
+	struct input_history history = {			\
+	/* items: */	{ D_LIST_HEAD(history.entries) },	\
+	/* size: */	0,					\
+	/* dirty: */	0,					\
+	/* nosave: */	0,					\
+	}
+
 #define add_to_history_list(history, entry)			\
 	do {							\
 		add_to_list((history)->entries, entry);		\
@@ -37,8 +42,9 @@ struct input_history {
 
 void add_to_input_history(struct input_history *, unsigned char *, int);
 
-void do_tab_compl(struct terminal *, struct list_head *, struct window *);
-void do_tab_compl_unambiguous(struct terminal *, struct list_head *, struct window *);
+void do_tab_compl(struct dialog_data *, struct list_head *);
+void do_tab_compl_file(struct dialog_data *, struct list_head *);
+void do_tab_compl_unambiguous(struct dialog_data *, struct list_head *);
 
 /* Load history file from elinks home. */
 int load_input_history(struct input_history *history, unsigned char *filename);
@@ -47,4 +53,6 @@ int load_input_history(struct input_history *history, unsigned char *filename);
  * from 0 in case of failure, 0 on success. */
 int save_input_history(struct input_history *history, unsigned char *filename);
 
+void dlg_set_history(struct widget_data *);
+
 #endif
